@@ -1,40 +1,56 @@
-# $Id: Namespace.pm 32372 2009-04-14 06:21:48Z daisuke $
 
 package Data::Localize::Namespace;
 use Any::Moose;
 use Module::Pluggable::Object;
 use Encode ();
+use Data::Localize::Util qw(_alias_and_deprecate);
 
 with 'Data::Localize::Localizer';
 
-has 'namespaces' => (
+has _namespaces => (
     is => 'rw',
     isa => 'ArrayRef',
+    default => sub { [] },
+    init_arg => 'namespaces',
 );
 
+has _loaded_classes => (
+    is => 'ro',
+    isa => 'HashRef',
+    default => sub { +{} }
+);
+
+has _failed_classes => (
+    is => 'ro',
+    isa => 'HashRef',
+    default => sub { +{} }
+);
+
+_alias_and_deprecate lexicon_get => 'get_lexicon';
+
 __PACKAGE__->meta->make_immutable;
 
 no Any::Moose;
 
 sub add_namespaces {
     my $self = shift;
-    unshift @{ $self->namespaces }, @_;
+    unshift @{ $self->_namespaces }, @_;
 }
 
-sub all_namespaces {
+sub namespaces {
     my $self = shift;
-    return @{ $self->namespaces };
+    return @{ $self->_namespaces };
 }
 
 sub register {
     my ($self, $loc) = @_;
     my $finder = Module::Pluggable::Object->new(
         'require' => 1,
-        search_path => [ $self->all_namespaces ]
+        search_path => [ $self->namespaces ]
     );
 
     # find the languages that we currently support
-    my $re = join('|', $self->all_namespaces);
+    my $re = join('|', $self->namespaces);
     foreach my $plugin ($finder->plugins) {
         $plugin =~ s/^(?:$re):://;
         $plugin =~ s/::/_/g;
@@ -43,38 +59,39 @@ sub register {
     $loc->add_localizer_map('*', $self);
 }
 
-our %LOADED;
-our %LOAD_FAILED;
-sub lexicon_get {
+sub get_lexicon {
     my ($self, $lang, $id) = @_;
 
     $lang =~ s/-/_/g;
 
-    foreach my $namespace ($self->all_namespaces) {
+    my $LOADED = $self->_loaded_classes;
+    my $FAILED = $self->_failed_classes;
+    foreach my $namespace ($self->namespaces) {
         my $klass = "$namespace\::$lang";
 
-        if ($LOAD_FAILED{ $klass }++) {
+        if ($FAILED->{ $klass }++) {
             if (Data::Localize::DEBUG()) {
-                print STDERR "[Data::Localize::Namespace]: lexicon_get - Already attempted loading $klass and failed. Skipping...\n";
+                print STDERR "[Data::Localize::Namespace]: get_lexicon - Already attempted loading $klass and failed. Skipping...\n";
             }
+            next;
         }
 
         if (Data::Localize::DEBUG()) {
-            print STDERR "[Data::Localize::Namespace]: lexicon_get - Trying $klass\n";
+            print STDERR "[Data::Localize::Namespace]: get_lexicon - Trying $klass\n";
         }
 
         # Catch the very weird case where is_class_loaded() returns true
         # but the class really hasn't been loaded yet.
         no strict 'refs';
         my $first_load = 0;
-        if (! $LOADED{$klass}) {
+        if (! $LOADED->{$klass}) {
             if (defined %{"$klass\::Lexicon"} && defined %{"$klass\::"}) {
                 if (Data::Localize::DEBUG()) {
-                    print STDERR "[Data::Localize::Namespace]: lexicon_get - class already loaded\n";
+                    print STDERR "[Data::Localize::Namespace]: get_lexicon - class already loaded\n";
                 }
             } else {
                 if (Data::Localize::DEBUG()) {
-                    print STDERR "[Data::Localize::Namespace]: lexicon_get - loading $klass\n";
+                    print STDERR "[Data::Localize::Namespace]: get_lexicon - loading $klass\n";
                 }
 
                 my $code = 
@@ -85,16 +102,16 @@ sub lexicon_get {
                 eval($code);
                 if ($@) {
                     if (Data::Localize::DEBUG()) {
-                        print STDERR "[Data::Localize::Namespace]: lexicon_get - Failed to load $klass: $@\n";
-                        $LOAD_FAILED{$klass}++;
+                        print STDERR "[Data::Localize::Namespace]: get_lexicon - Failed to load $klass: $@\n";
+                        $FAILED->{$klass}++;
                     }
                     next;
                 }
             }
             if (Data::Localize::DEBUG()) {
-                print STDERR "[Data::Localize::Namespace]: lexicon_get - setting $klass to already loaded\n";
+                print STDERR "[Data::Localize::Namespace]: get_lexicon - setting $klass to already loaded\n";
             }
-            $LOADED{$klass}++;
+            $LOADED->{$klass}++;
             $first_load = 1;
         }
 
@@ -154,15 +171,24 @@ Data::Localize::Namespace - Acquire Lexicons From Module %Lexicon Hash
 
 =head1 METHODS
 
-=head2 register
+=head2 add_namespaces
 
-Registeres this localizer to the Data::Localize object
+Add a new namespace to the END of the namespace list
 
-=head2 lexicon_get 
+=head2 get_lexicon 
 
 Looks up lexicon data from given namespaces. Packages must be discoverable
 via Module::Pluggable::Object, with a package name like YourNamespace::lang
 
+=head2 namespaces
+
+Get all the namespaces that this localizer will look up, in the order that
+they will be looked up.
+
+=head2 register
+
+Registeres this localizer to the Data::Localize object
+
 =head1 AUTHOR
 
 Daisuke Maki C<< <daisuke@endeworks.jp> >>
